ColOrCols

Enum ColOrCols 

pub enum ColOrCols<'a> {
    Col(ColId),
    ColList(&'a ColList),
}
A borrowed list of columns or a single one.

Variants



Col(ColId)

A single column.



ColList(&'a ColList)

A list of columns.

Implementations

Source

impl ColOrCols<'_>

pub fn as_singleton(&self) -> Option<ColId>

Returns Some(col) iff self is singleton.

pub fn iter(&self) -> impl '_ + Iterator<Item = ColId>

Returns an iterator over all the columns in this list.

pub fn len(&self) -> u16

Returns the length of this list.

pub fn is_empty(&self) -> bool

Returns whether the list is empty.

pub fn to_owned(self) -> ColList

Converts to a ColList.