pub enum FunctionId {
Reducer(ReducerId),
Procedure(ProcedureId),
}Expand description
An id for a function exported from a module, which may be a reducer or a procedure.
Variants
Reducer(ReducerId)
Procedure(ProcedureId)
Implementations
Sourceimpl FunctionId
impl FunctionId
Sourcepub fn is_reducer(&self) -> bool
pub fn is_reducer(&self) -> bool
Returns true if this is a FunctionId::Reducer, otherwise false
Sourcepub fn as_reducer_mut(&mut self) -> Option<&mut ReducerId>
pub fn as_reducer_mut(&mut self) -> Option<&mut ReducerId>
Optionally returns mutable references to the inner fields if this is a FunctionId::Reducer, otherwise None
Sourcepub fn as_reducer(&self) -> Option<&ReducerId>
pub fn as_reducer(&self) -> Option<&ReducerId>
Optionally returns references to the inner fields if this is a FunctionId::Reducer, otherwise None
Sourcepub fn into_reducer(self) -> Result<ReducerId, Self>
pub fn into_reducer(self) -> Result<ReducerId, Self>
Returns the inner fields if this is a FunctionId::Reducer, otherwise returns back the enum in the Err case of the result
Sourcepub fn is_procedure(&self) -> bool
pub fn is_procedure(&self) -> bool
Returns true if this is a FunctionId::Procedure, otherwise false
Sourcepub fn as_procedure_mut(&mut self) -> Option<&mut ProcedureId>
pub fn as_procedure_mut(&mut self) -> Option<&mut ProcedureId>
Optionally returns mutable references to the inner fields if this is a FunctionId::Procedure, otherwise None
Sourcepub fn as_procedure(&self) -> Option<&ProcedureId>
pub fn as_procedure(&self) -> Option<&ProcedureId>
Optionally returns references to the inner fields if this is a FunctionId::Procedure, otherwise None
Sourcepub fn into_procedure(self) -> Result<ProcedureId, Self>
pub fn into_procedure(self) -> Result<ProcedureId, Self>
Returns the inner fields if this is a FunctionId::Procedure, otherwise returns back the enum in the Err case of the result