#[repr(transparent)]pub struct ConstraintId(pub u32);Expand description
An identifier for a constraint, unique within a database.
Tuple Fields
0: u32Implementations
Sourceimpl ConstraintId
impl ConstraintId
Sourceimpl ConstraintId
impl ConstraintId
Sourcepub const SENTINEL: Self
pub const SENTINEL: Self
The sentinel value for this type. This will be initialized to a valid ID upon insertion into a system table as a primary key.
Sourcepub fn is_sentinel(self) -> bool
pub fn is_sentinel(self) -> bool
Check if this ID is the sentinel value.