#[repr(transparent)]pub struct ViewFnPtr(pub u32);Expand description
The index of a view as defined in a module’s view lists.
Unlike reducers and procedures, the module maintains two lists for views.
One for ViewContext and the other for AnonymousViewContext.
As such, this index does not uniquely identify a view on its own.
You must know which list this index refers to.
Tuple Fields
0: u32Implementations