#[repr(transparent)]pub struct ViewId(pub u32);Expand description
An identifier for a view, unique within a database.
It is stored in the db as the primary key column of st_view.
Tuple Fields
0: u32Implementations